#ifndef QtProgress_TULIP
#define QtProgress_TULIP
#include <string>
#include <qprogressdialog.h>
#include <qwidget.h>
#include <tulip/PluginProgress.h>

class MyProgress:public QWidget,public PluginProgress {

  Q_OBJECT

public:
  MyProgress(QWidget* parent,std::string text);
  virtual ~MyProgress();
  bool progress_handler(int i,int j);
public slots:
  void stopCompute();
public:
  QProgressDialog *myprog;
  bool compute;
  std::string label;
  QWidget* parent;
};

#endif
